kitexample

package
v0.0.0-...-a091d1a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 8, 2024 License: Apache-2.0 Imports: 11 Imported by: 0

README

The Gizmo/App Engine 2nd Generation Example

This example shows how to use service initiation in the Gizmo server to fetch secrets from Vault.

To run this against your own Vault installation, update the environment values in the Makefile. To run locally, run make run or make test.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewService

func NewService() (*service, error)

Types

This section is empty.

Directories

Path Synopsis
cmd
server command

Jump to